# Hakisto

## Logging reimagined...

The name: **Hakisto** means Logger in Esperanto.

## Simple...

```python
from hakisto import logger

logger.warning('something is fishy...')
```

Starts logging to console and file.

### Example output

```
hakisto-demo-color
```

![](./docs/images/demo-color.png)

```
hakisto-demo-critical
```

![](./docs/images/demo-critical.png)

```
hakisto-demo-traceback
```

![](./docs/images/demo-traceback.png)

## Installation

```
pip install hakisto
```

or get the source from [gitlab.com/hakisto/logger](https://gitlab.com/hakisto/logger/).

## Documentation

[Read the Docs](https://hakisto.readthedocs.io)

## Changes

| Version | Changes                                                                   |
|---------|---------------------------------------------------------------------------|
| `0.1.1` | No functional changes, just making **README** and **Read the Docs** work. | 